==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchListenerFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent() {
  }
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchListener());

    if (instance != null) {
      this.withListener(instance.getListener());
      this.withListener(instance.getListener());
    }
  }
  private EnvoyFilterListenerMatchBuilder listener;
  public EnvoyFilterListenerMatch buildListener() {
    return this.listener!=null ?this.listener.build():null;
  }
  public A withListener(EnvoyFilterListenerMatch listener) {
    _visitables.get("listener").remove(this.listener);
    if (listener!=null){ this.listener= new EnvoyFilterListenerMatchBuilder(listener); _visitables.get("listener").add(this.listener);} else { this.listener = null; _visitables.get("listener").remove(this.listener); } return (A) this;
  }
  public boolean hasListener() {
    return this.listener != null;
  }
  public ListenerNested<A> withNewListener() {
    return new ListenerNested(null);
  }
  public ListenerNested<A> withNewListenerLike(EnvoyFilterListenerMatch item) {
    return new ListenerNested(item);
  }
  public ListenerNested<A> editListener() {
    return withNewListenerLike(java.util.Optional.ofNullable(buildListener()).orElse(null));
  }
  public ListenerNested<A> editOrNewListener() {
    return withNewListenerLike(java.util.Optional.ofNullable(buildListener()).orElse(new EnvoyFilterListenerMatchBuilder().build()));
  }
  public ListenerNested<A> editOrNewListenerLike(EnvoyFilterListenerMatch item) {
    return withNewListenerLike(java.util.Optional.ofNullable(buildListener()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchListenerFluent that = (EnvoyFilterEnvoyConfigObjectMatchListenerFluent) o;
    if (!java.util.Objects.equals(listener, that.listener)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(listener,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (listener != null) { sb.append("listener:"); sb.append(listener); }
    sb.append("}");
    return sb.toString();
  }
  public class ListenerNested<N> extends EnvoyFilterListenerMatchFluent<ListenerNested<N>> implements Nested<N>{
    ListenerNested(EnvoyFilterListenerMatch item) {
      this.builder = new EnvoyFilterListenerMatchBuilder(this, item);
    }
    EnvoyFilterListenerMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchListenerFluent.this.withListener(builder.build());
    }
    public N endListener() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchListenerFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A extends EnvoyFilterEnvoyConfigObjectMatchListenerFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent() {
  }
  
  public EnvoyFilterEnvoyConfigObjectMatchListenerFluent(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    this.copyInstance(instance);
  }
  private EnvoyFilterListenerMatchBuilder listener;
  
  protected void copyInstance(EnvoyFilterEnvoyConfigObjectMatchListener instance) {
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchListener());
  
    if (instance != null) {
        this.withListener(instance.getListener());
        this.withListener(instance.getListener());
      }
  }
  
  public EnvoyFilterListenerMatch buildListener() {
    return this.listener!=null ?this.listener.build():null;
  }
  
  public A withListener(EnvoyFilterListenerMatch listener) {
    _visitables.get("listener").remove(this.listener);
    if (listener!=null){ this.listener= new EnvoyFilterListenerMatchBuilder(listener); _visitables.get("listener").add(this.listener);} else { this.listener = null; _visitables.get("listener").remove(this.listener); } return (A) this;
  }
  
  public boolean hasListener() {
    return this.listener != null;
  }
  
  public ListenerNested<A> withNewListener() {
    return new ListenerNested(null);
  }
  
  public ListenerNested<A> withNewListenerLike(EnvoyFilterListenerMatch item) {
    return new ListenerNested(item);
  }
  
  public ListenerNested<A> editListener() {
    return withNewListenerLike(java.util.Optional.ofNullable(buildListener()).orElse(null));
  }
  
  public ListenerNested<A> editOrNewListener() {
    return withNewListenerLike(java.util.Optional.ofNullable(buildListener()).orElse(new EnvoyFilterListenerMatchBuilder().build()));
  }
  
  public ListenerNested<A> editOrNewListenerLike(EnvoyFilterListenerMatch item) {
    return withNewListenerLike(java.util.Optional.ofNullable(buildListener()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectMatchListenerFluent that = (EnvoyFilterEnvoyConfigObjectMatchListenerFluent) o;
    if (!java.util.Objects.equals(listener, that.listener)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(listener,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (listener != null) { sb.append("listener:"); sb.append(listener); }
    sb.append("}");
    return sb.toString();
  }
  public class ListenerNested<N> extends EnvoyFilterListenerMatchFluent<ListenerNested<N>> implements Nested<N>{
    ListenerNested(EnvoyFilterListenerMatch item) {
      this.builder = new EnvoyFilterListenerMatchBuilder(this, item);
    }
    EnvoyFilterListenerMatchBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectMatchListenerFluent.this.withListener(builder.build());
    }
    
    public N endListener() {
      return and();
    }
    
  
  }

}
